=======
Credits
=======

Development Lead
----------------

* Aaron F. Kurz <aaron.kurz@unisg.ch>

Contributors
------------

* Ronny Seiger <ronny.seiger@unisg.ch>
* Marco Franceschetti <marco.franceschetti@unisg.ch>
* Barbara Weber <barbara.weber@unisg.ch>
